@@ -315,5 +315,66 @@ def transpose_location_summary(experiment, summary):
     
     return out
     
+def transpose_barcode_summary(experiment, summary):
+    """
+    Transpose barcode summary  to well summary where each row corresponds to 
+    a different well.
+
+    Parameters
+    ----------
+    experiment : LibraryExperiment
+        Object holding input parameters.
+    summary : pandas dataframe
+        output table holding barcode information and well locations
+
+    Returns
+    -------
+    out : pandas dataframe
+       well summary
+
+    """
+    def append2cell(cell, val):
+        if cell == "nan":
+            out = val
+        else:
+            out = ";".join([str(cell),str(val)])
+        return out
+
     
+    dims = experiment.pool_dims
+    
+    well_pools = list(product(*dims.values()))
+    
+    wells = np.array(["_".join(w) for w in well_pools])
+    wells = wells.reshape(len(well_pools),1)
+    well_pools = np.array(well_pools)
+    
+    incols = ["Well"] +list(dims.keys()) + ["Ambiguity", "Barcode"]
+    outcols = ["Ambiguity", "Barcode"]
+
+    dummy = np.empty((well_pools.shape[0],2))
+    dummy[:] = np.nan
+
+    grid = np.hstack([wells, well_pools, dummy])
+
+    out = pd.DataFrame(grid, columns= incols)
+    out.index = out["Well"]
+
+    for row  in summary.itertuples(index =False):
+        w = row[1]
+        if type(w) == float and  math.isnan(w):
+            continue
+        else:
+            w = w.split(";")
+           
+            amb = row[3]
+            
+            bar = row[0]
+            outvals = [amb,bar]
+           
+            for i in w:
+                for j,v in zip(outcols,outvals):
+                    out.loc[i,j] = append2cell(out.loc[i,j], v)
+    
+    return out
     
